@@ -1,5 +1,6 @@
 import sys
 
+import django
 from django.apps import apps
 from django.core.management.commands.makemigrations import Command as BaseCommand
 
@@ -14,7 +15,10 @@ class Command(BaseCommand):
 
     # Checks disabled because the django-linear-migrations' checks would
     # prevent us continuing
-    requires_system_checks = False
+    if django.VERSION < (3, 2):
+        requires_system_checks = False
+    else:
+        requires_system_checks = []
 
     def add_arguments(self, parser):
         parser.add_argument(
@@ -23,8 +27,14 @@ class Command(BaseCommand):
             nargs="*",
             help="Specify the app label(s) to create max migration files for.",
         )
+        parser.add_argument(
+            "--dry-run",
+            action="store_true",
+            default=False,
+            help="Actually create the files.",
+        )
 
-    def handle(self, *app_labels, **options):
+    def handle(self, *app_labels, dry_run, **options):
         # Copied check from makemigrations
         app_labels = set(app_labels)
         has_bad_labels = False
@@ -48,11 +58,18 @@ class Command(BaseCommand):
 
             max_migration_txt = migration_details.dir / "max_migration.txt"
             if not max_migration_txt.exists():
-                max_migration_name = max(migration_details.names)
-                max_migration_txt.write_text(max_migration_name + "\n")
-                self.stdout.write(
-                    "Created max_migration.txt for {}".format(app_config.label)
-                )
+                if not dry_run:
+                    max_migration_name = max(migration_details.names)
+                    max_migration_txt.write_text(max_migration_name + "\n")
+                    self.stdout.write(
+                        "Created max_migration.txt for {}.".format(app_config.label)
+                    )
+                else:
+                    self.stdout.write(
+                        "Would create max_migration.txt for {}.".format(
+                            app_config.label
+                        )
+                    )
                 any_created = True
 
         if not any_created:
